# BlobStorage
A simple python package for storing and retrieving blobs of data from Azure Blob Storage.

This is a simple example package. You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.